@@ -91,7 +91,7 @@ static const time_t *tagTime(const struct Message *msg) {
 	static time_t time;
 	struct tm tm;
 	if (!msg->tags[TagTime]) return NULL;
-	if (!strptime(msg->tags[TagTime], "%FT%T", &tm)) return NULL;
+	if (!strptime(msg->tags[TagTime], "%Y-%m-%dT%T", &tm)) return NULL;
 	time = timegm(&tm);
 	return &time;
 }
@@ -208,18 +208,18 @@ static void handleAuthenticate(struct Message *msg) {
 		return;
 	}
 
-	byte buf[299];
+	byte buf[299] = {0};
 	size_t len = 1 + strlen(self.plain);
-	if (sizeof(buf) < len) errx(EX_CONFIG, "SASL PLAIN is too long");
-	buf[0] = 0;
-	for (size_t i = 0; self.plain[i]; ++i) {
-		buf[1 + i] = (self.plain[i] == ':' ? 0 : self.plain[i]);
-	}
+	if (sizeof(buf) < len) errx(EX_USAGE, "SASL PLAIN is too long");
+	memcpy(&buf[1], self.plain, len - 1);
+	byte *sep = memchr(buf, ':', len);
+	if (!sep) errx(EX_USAGE, "SASL PLAIN missing colon");
+	*sep = 0;
 
 	char b64[BASE64_SIZE(sizeof(buf))];
 	base64(b64, buf, len);
 	ircFormat("AUTHENTICATE ");
-	ircSend(b64, BASE64_SIZE(len));
+	ircSend(b64, BASE64_SIZE(len) - 1);
 	ircFormat("\r\n");
 
 	explicit_bzero(b64, sizeof(b64));
@@ -571,7 +571,7 @@ static void handleReplyWho(struct Message *msg) {
 	require(msg, false, 7);
 	if (who.ptr == who.buf) {
 		who.ptr = seprintf(
-			who.ptr, who.end, "The operators of \3%02d%s\3 are ",
+			who.ptr, who.end, "The council of \3%02d%s\3 are ",
 			hash(msg->params[1]), msg->params[1]
 		);
 	}
@@ -1148,7 +1148,7 @@ static void handleReplyAway(struct Message *msg) {
 		id = idFor(msg->params[1]);
 	}
 	uiFormat(
-		id, Warm, tagTime(msg),
+		id, (id == Network ? Warm : Cold), tagTime(msg),
 		"\3%02d%s\3\tis away: %s",
 		completeColor(id, msg->params[1]), msg->params[1], msg->params[2]
 	);
@@ -1321,6 +1321,7 @@ static const struct Handler {
 	{ "317", +ReplyWhois, handleReplyWhoisIdle },
 	{ "318", -ReplyWhois, handleReplyEndOfWhois },
 	{ "319", +ReplyWhois, handleReplyWhoisChannels },
+	{ "320", +ReplyWhois, handleReplyWhoisGeneric },
 	{ "322", +ReplyList, handleReplyList },
 	{ "323", -ReplyList, NULL },
 	{ "324", -ReplyMode, handleReplyChannelModeIs },
